@@ -1,5 +1,5 @@
 package MooseX::Role::WithOverloading;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 # ABSTRACT: Roles which support overloading
 
 use XSLoader;
@@ -34,6 +34,7 @@ sub init_meta {
 
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -42,7 +43,7 @@ MooseX::Role::WithOverloading - Roles which support overloading
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -78,12 +79,18 @@ defines overloaded operators and allows those operator overloadings to be
 composed into the classes/roles/instances it's compiled to, while plain
 L<Moose::Role>s would lose the overloading.
 
-=for Pod::Coverage init_meta
+=begin Pod::Coverage
+
+init_meta
+
+=end Pod::Coverage
+
+
 
 =head1 AUTHORS
 
-Florian Ragwitz <rafl@debian.org>
-Tomas Doran <bobtfish@bobtfish.net>
+  Florian Ragwitz <rafl@debian.org>
+  Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -92,5 +99,6 @@ This software is copyright (c) 2010 by Florian Ragwitz.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut
+=cut 
+
 
