@@ -1,5 +1,5 @@
 package MooseX::Role::WithOverloading::Meta::Role::Application::FixOverloadedRefs;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -14,6 +14,7 @@ if ($] < 5.008009) {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -22,14 +23,20 @@ MooseX::Role::WithOverloading::Meta::Role::Application::FixOverloadedRefs
 
 =head1 VERSION
 
-version 0.04
+version 0.05
+
+=begin Pod::Coverage
+
+reset_amagic
+
+=end Pod::Coverage
+
 
-=for Pod::Coverage reset_amagic
 
 =head1 AUTHORS
 
-Florian Ragwitz <rafl@debian.org>
-Tomas Doran <bobtfish@bobtfish.net>
+  Florian Ragwitz <rafl@debian.org>
+  Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -38,5 +45,6 @@ This software is copyright (c) 2010 by Florian Ragwitz.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut
+=cut 
+
 
